<?php
if (!defined('ABSPATH')) die('No direct access allowed');
?>
<div id="updraft-deinstall-dialog-content">
    <p>Please select what to do with your data:</p>
    <fieldset>
        <label>
            <input type="radio" name="updraft_deinstall_option" value="keep" checked>
            Keep all data
        </label><br>
        <label>
            <input type="radio" name="updraft_deinstall_option" value="delete">
            Delete all data
        </label>
    </fieldset>
</div>