<button>
	{{#if iconLeft}}
		<tu-icon instance="{{iconLeft}}"></tu-icon>
	{{/if}}
	<span class="tu-button-content">{{innerContent}}</span>
	{{#if iconRight}}
		<tu-icon instance="{{iconRight}}"></tu-icon>
	{{/if}}
</button>
