import { TUHTMLElement } from "../../helpers/tu-html-element";

/**
 * TUIcon web-component.
 */
class TUIcon extends TUHTMLElement {
	/**
	 * Constructor.
	 */
	constructor() {
		super();
	}
}

customElements.define("tu-icon", TUIcon);