@use "./helpers/responsive-variables-generator.scss" as *;
@use "./helpers/global-variables.scss" as *;

// Components.
@use "./components/icon/icon.scss" as *;
@use "./components/button/button.scss" as *;
@use "./components/column-and-row/column-and-row.scss" as *;

@font-face {
	font-family: "Inter";
	font-style: normal;
	font-weight: 400;
	font-display: swap;
	src: url('./fonts/Inter/Inter-Regular.woff2') format('woff2');
}

@font-face {
	font-family: "Inter";
	font-style: italic;
	font-weight: 400;
	font-display: swap;
	src: url('./fonts/Inter/Inter-Italic.woff2') format('woff2');
}

@font-face {
	font-family: "Inter";
	font-style: normal;
	font-weight: 700;
	font-display: swap;
	src: url('./fonts/Inter/Inter-Bold.woff2') format('woff2');
}

@font-face {
	font-family: "Inter";
	font-style: italic;
	font-weight: 700;
	font-display: swap;
	src: url('./fonts/Inter/Inter-BoldItalic.woff2') format('woff2');
}

@supports (font-variation-settings: normal) {
	@font-face {
		font-family: "Inter";
		font-style: normal;
		font-weight: 100 900;
		font-display: swap;
		src: url('./fonts/Inter/InterVariable.woff2') format('woff2');
	}

	@font-face {
		font-family: "Inter";
		font-style: italic;
		font-weight: 100 900;
		font-display: swap;
		src: url('./fonts/Inter/InterVariable-Italic.woff2') format('woff2');
	}
}
